==> zio-aws-ec2_2.12-5.17.152.1-sources.jar: zio/aws/ec2/model/LicenseConfigurationRequest.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class LicenseConfigurationRequest(
    licenseConfigurationArn: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.LicenseConfigurationRequest = {
    import LicenseConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.LicenseConfigurationRequest
      .builder()
      .optionallyWith(
        licenseConfigurationArn.map(value => value: java.lang.String)
      )(_.licenseConfigurationArn)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.LicenseConfigurationRequest.ReadOnly =
    zio.aws.ec2.model.LicenseConfigurationRequest.wrap(buildAwsValue())
}
object LicenseConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.LicenseConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.LicenseConfigurationRequest =
      zio.aws.ec2.model.LicenseConfigurationRequest(
        licenseConfigurationArn.map(value => value)
      )
    def licenseConfigurationArn: Option[String]
    def getLicenseConfigurationArn: ZIO[Any, AwsError, String] = AwsError
      .unwrapOptionField("licenseConfigurationArn", licenseConfigurationArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.LicenseConfigurationRequest
  ) extends zio.aws.ec2.model.LicenseConfigurationRequest.ReadOnly {
    override val licenseConfigurationArn: Option[String] =
      scala.Option(impl.licenseConfigurationArn()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.LicenseConfigurationRequest
  ): zio.aws.ec2.model.LicenseConfigurationRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.19.8.4-sources.jar: zio/aws/ec2/model/LicenseConfigurationRequest.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class LicenseConfigurationRequest(
    licenseConfigurationArn: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.LicenseConfigurationRequest = {
    import LicenseConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.LicenseConfigurationRequest
      .builder()
      .optionallyWith(
        licenseConfigurationArn.map(value => value: java.lang.String)
      )(_.licenseConfigurationArn)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.LicenseConfigurationRequest.ReadOnly =
    zio.aws.ec2.model.LicenseConfigurationRequest.wrap(buildAwsValue())
}
object LicenseConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.LicenseConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.LicenseConfigurationRequest =
      zio.aws.ec2.model.LicenseConfigurationRequest(
        licenseConfigurationArn.map(value => value)
      )
    def licenseConfigurationArn: Optional[String]
    def getLicenseConfigurationArn: ZIO[Any, AwsError, String] = AwsError
      .unwrapOptionField("licenseConfigurationArn", licenseConfigurationArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.LicenseConfigurationRequest
  ) extends zio.aws.ec2.model.LicenseConfigurationRequest.ReadOnly {
    override val licenseConfigurationArn: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.licenseConfigurationArn())
        .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.LicenseConfigurationRequest
  ): zio.aws.ec2.model.LicenseConfigurationRequest.ReadOnly = new Wrapper(impl)
}
